# Code of Conduct

* Be nice -- motivated people are more creative and more productive, the nature of any interaction should be such that it leads to more motivation, not less
* Be constructive -- getting a fix for a problem, or identifying a concrete path forward should be the focus of any discussion  
